==> qtjambi-webenginecore-debuginfo-macos-5.15.20.jar: sources/QtJambiWebEngineCore/QWebEngineRegisterProtocolHandlerRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineregisterprotocolhandlerrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineRegisterProtocolHandlerRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineRegisterProtocolHandlerRequest")
    QWebEngineRegisterProtocolHandlerRequest *_ptr = reinterpret_cast<QWebEngineRegisterProtocolHandlerRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineRegisterProtocolHandlerRequest()
void __qt_construct_QWebEngineRegisterProtocolHandlerRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineRegisterProtocolHandlerRequest()")
    Q_UNUSED(__java_arguments)
    QWebEngineRegisterProtocolHandlerRequest *__qt_this = new(__qtjambi_ptr) QWebEngineRegisterProtocolHandlerRequest();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineRegisterProtocolHandlerRequest, sizeof(QWebEngineRegisterProtocolHandlerRequest), typeid(QWebEngineRegisterProtocolHandlerRequest), false, &deleter_QWebEngineRegisterProtocolHandlerRequest, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWebEngineRegisterProtocolHandlerRequest(QWebEngineRegisterProtocolHandlerRequest)
void __qt_construct_QWebEngineRegisterProtocolHandlerRequest_cref_QWebEngineRegisterProtocolHandlerRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineRegisterProtocolHandlerRequest(QWebEngineRegisterProtocolHandlerRequest)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineRegisterProtocolHandlerRequest& __qt_other0 = qtjambi_cast<const QWebEngineRegisterProtocolHandlerRequest& >(__jni_env, other0);
    QWebEngineRegisterProtocolHandlerRequest *__qt_this = new(__qtjambi_ptr) QWebEngineRegisterProtocolHandlerRequest(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest(QWebEngineRegisterProtocolHandlerRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_2Lio_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest(QWebEngineRegisterProtocolHandlerRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineRegisterProtocolHandlerRequest_cref_QWebEngineRegisterProtocolHandlerRequest, sizeof(QWebEngineRegisterProtocolHandlerRequest), typeid(QWebEngineRegisterProtocolHandlerRequest), false, &deleter_QWebEngineRegisterProtocolHandlerRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebEngineRegisterProtocolHandlerRequest
void __qt_destruct_QWebEngineRegisterProtocolHandlerRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineRegisterProtocolHandlerRequest")
    reinterpret_cast<QWebEngineRegisterProtocolHandlerRequest*>(ptr)->~QWebEngineRegisterProtocolHandlerRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineRegisterProtocolHandlerRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_equals_1native_1cref_1QWebEngineRegisterProtocolHandlerRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID that0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const", __qt_this)
        const QWebEngineRegisterProtocolHandlerRequest& __qt_that0 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(that0);
        __java_return_value = (*__qt_this) == __qt_that0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineRegisterProtocolHandlerRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineRegisterProtocolHandlerRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineRegisterProtocolHandlerRequest::scheme()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_scheme_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::scheme()const", __qt_this)
        QString __qt_return_value = __qt_this->scheme();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineRegisterProtocolHandlerRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineRegisterProtocolHandlerRequest>("QWebEngineRegisterProtocolHandlerRequest", "io/qt/webengine/core/QWebEngineRegisterProtocolHandlerRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineRegisterProtocolHandlerRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineRegisterProtocolHandlerRequest, nullptr)
       ,ConstructorInfo(&__qt_construct_QWebEngineRegisterProtocolHandlerRequest_cref_QWebEngineRegisterProtocolHandlerRequest, "Lio/qt/webengine/core/QWebEngineRegisterProtocolHandlerRequest;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineRegisterProtocolHandlerRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineRegisterProtocolHandlerRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineRegisterProtocolHandlerRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineRegisterProtocolHandlerRequest);
    registerMetaType<QWebEngineRegisterProtocolHandlerRequest>("QWebEngineRegisterProtocolHandlerRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-macos-6.5.3.jar: sources/QtJambiWebEngineCore/QWebEngineRegisterProtocolHandlerRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineregisterprotocolhandlerrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineRegisterProtocolHandlerRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineRegisterProtocolHandlerRequest")
    QWebEngineRegisterProtocolHandlerRequest *_ptr = reinterpret_cast<QWebEngineRegisterProtocolHandlerRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineRegisterProtocolHandlerRequest()
void __qt_construct_QWebEngineRegisterProtocolHandlerRequest_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineRegisterProtocolHandlerRequest()")
    Q_UNUSED(__java_arguments)
    QWebEngineRegisterProtocolHandlerRequest *__qt_this = new(__qtjambi_ptr) QWebEngineRegisterProtocolHandlerRequest();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineRegisterProtocolHandlerRequest
void __qt_destruct_QWebEngineRegisterProtocolHandlerRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineRegisterProtocolHandlerRequest")
    reinterpret_cast<QWebEngineRegisterProtocolHandlerRequest*>(ptr)->~QWebEngineRegisterProtocolHandlerRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::QWebEngineRegisterProtocolHandlerRequest()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineRegisterProtocolHandlerRequest_0, sizeof(QWebEngineRegisterProtocolHandlerRequest), typeid(QWebEngineRegisterProtocolHandlerRequest), false, &deleter_QWebEngineRegisterProtocolHandlerRequest, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineRegisterProtocolHandlerRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_operator_1equal_1native_1cref_1QWebEngineRegisterProtocolHandlerRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID that0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::operator==(QWebEngineRegisterProtocolHandlerRequest)const", __qt_this)
        const QWebEngineRegisterProtocolHandlerRequest& __qt_that0 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(that0);
        __java_return_value = (*__qt_this) == __qt_that0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineRegisterProtocolHandlerRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineRegisterProtocolHandlerRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineRegisterProtocolHandlerRequest::scheme()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_scheme_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineRegisterProtocolHandlerRequest::scheme()const", __qt_this)
        QString __qt_return_value = __qt_this->scheme();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineRegisterProtocolHandlerRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineRegisterProtocolHandlerRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineRegisterProtocolHandlerRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineRegisterProtocolHandlerRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineRegisterProtocolHandlerRequest>("QWebEngineRegisterProtocolHandlerRequest", "io/qt/webengine/core/QWebEngineRegisterProtocolHandlerRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineRegisterProtocolHandlerRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineRegisterProtocolHandlerRequest_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QWebEngineRegisterProtocolHandlerRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineRegisterProtocolHandlerRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineRegisterProtocolHandlerRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineRegisterProtocolHandlerRequest);
    registerMetaType<QWebEngineRegisterProtocolHandlerRequest>("QWebEngineRegisterProtocolHandlerRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
